<?php

namespace Ems\portalGestor\Service;

use Ems\portalGestor\Repository\VinculoRepository;
use Ems\portalGestor\Util\HcmServices;

class DocumentoService {
    /** @var HcmServices */
    protected $hcmServices;

    /** @var VinculoRepository */
    protected $vinculoRepository;

    public function __construct(
        HcmServices $hcmServices,
        VinculoRepository $vinculoRepository
    ) {
        $this->hcmServices = $hcmServices;
        $this->vinculoRepository = $vinculoRepository;
    }

    public function getDocumentosVinculo(
        int $nrOrg,
        int $nrVinculo,
            $nrCategoria
    ): array {
        $route = 'getDocumentosVinculo';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRVINCULOM' => $nrVinculo,
                'NRCATEGDOCUMENTO' => $nrCategoria,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $documentos = $result['dataset'][$route];

        return $documentos;
    }

    public function getCategoriasComDocumentoVinculo(
        int $nrOrg,
        int $nrVinculo
    ): array {
        $route = 'getCategoriasComDocumentoVinculo';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRVINCULOM' => $nrVinculo,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $categorias = $result['dataset'][$route];

        return $categorias;
    }

    public function getCategorias(
        int $nrOrg
    ): array {
        $route = 'getCategorias';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => '',
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $categorias = $result['dataset'][$route];

        return $categorias;
    }

    public function getTipos(
        int $nrOrg
    ): array {
        $route = 'getTipos';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => '',
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $tipos = $result['dataset'][$route];

        return $tipos;
    }

    public function downloadDocumento(
        int $nrOrg,
        int $nrAnexo
    ): array {
        $route = 'downloadDocumento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRANEXO' => $nrAnexo,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $file = $result['dataset'][$route];

        return $file;
    }

    public function saveDocumento(
        array $row
    ): bool {
        $route = 'saveDocumento';

        $nrOrg = (int) $row['NRORG'];

        $params = [
            'requestType' => 'Row',
            'row' => $row,
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $success = $result['dataset'][$route]['success'];

        return $success;
    }

    public function saveAssinatura(
        array $row
    ): bool {
        $nrOrg = (int) $row['NRORG'];

        $nrVinculo = (int) $row['NRVINCULOM'];
        $vinculo = $this->vinculoRepository->get($nrOrg, $nrVinculo);
        $row['NRPARCNEGOCIO'] = $vinculo['NRPARCNEGOCIO'];

        $route = 'saveAssinaturaEletronica';

        $params = [
            'requestType' => 'Row',
            'row' => $row,
        ];

        $this->hcmServices->send($route, $params, $nrOrg);
    }
}